@@ -105,9 +105,9 @@ define([
     }
     
     const DEF_BLOCK_ARG6_TYPE = {
-        NONE: 'none'
-        , ARGS: '*args'
-        , KWARGS: '**kwargs'
+        NONE: 'Default Args'
+        , ARGS: 'Variable Args'
+        , KWARGS: 'Keyword Args'
     }
 
     const DEF_BLOCK_SELECT_VALUE_ARG_TYPE = {
@@ -121,9 +121,13 @@ define([
     }
 
     const FOR_BLOCK_ARG3_TYPE = {
-        ZIP: 'zip'
-        , RANGE: 'range'
-        , ENUMERATE: 'enumerate'
+        // ZIP: 'zip'
+        // , RANGE: 'range'
+        // , ENUMERATE: 'enumerate'
+        // edit for block types
+        RANGE: 'Range'
+        , VARIABLE: 'Variable'
+        , TYPING: 'Typing'
     }
 
     const FOR_BLOCK_SELECT_VALUE_ARG_TYPE = {
@@ -504,7 +508,6 @@ define([
     /** const Option  */
     const VP_CLASS_APIBLOCK_OPTION_INPUT = 'vp-apiblock-option-input';
 
-
     /** const Css Style */
     const VP_CLASS_STYLE_FLEX_ROW = 'vp-apiblock-style-flex-row';
     const VP_CLASS_STYLE_FLEX_ROW_CENTER = 'vp-apiblock-style-flex-row-center';
