@@ -75,6 +75,12 @@ define([
                 iopub: {
                     output: function(msg) {
                         var result = String(msg.content["text"]);
+                        if (!result || result == 'undefined') {
+                            if (msg.content.data) {
+                                result = String(msg.content.data["text/plain"]);
+                            }
+                        }
+                        
                         callback(result);
                     }
                 }
@@ -250,11 +256,13 @@ define([
     VpFuncJS.prototype.getMetadata = function(id) {
         if (this.metadata == undefined)
             return "";
-        var len = this.metadata.options.length;
-        for (var i = 0; i < len; i++) {
-            var obj = this.metadata.options[i];
-            if (obj.id == id)
-                return obj.value;
+        if (this.metadata.options) {
+            var len = this.metadata.options.length;
+            for (var i = 0; i < len; i++) {
+                var obj = this.metadata.options[i];
+                if (obj.id == id)
+                    return obj.value;
+            }
         }
         return "";
     }
@@ -408,7 +416,7 @@ define([
      * @param {Array<function>} callback 선택 콜백 함수
      */
     VpFuncJS.prototype.openMultiBtnModal_new = function(message = "", submessage, buttons = new Array(), callbackList) {
-        var mbmModal = new vpMultiButtonModal_new.vpMultiButtonModal(message, submessage, buttons, callbackList);
+        var mbmModal = new vpMultiButtonModal_new.vpMultiButtonModal(message, submessage, buttons);
         mbmModal.openModal(callbackList);
     }
     return {'VpFuncJS': VpFuncJS};
