@@ -132,7 +132,7 @@ define([
                     var label = (obj.options_label != undefined? obj.options_label[idx]:opt);
                     var option = document.createElement('option');
                     $(option).attr({
-                        'id':opt,
+                        // 'id':opt,
                         'index':obj.index,
                         'name':obj.name,
                         'value':opt
@@ -179,6 +179,15 @@ define([
                 vp_generateVarSelect(tag, obj.var_type, obj.value);
                 tblInput.appendChild(tag);
                 break;
+            case 'textarea':
+                var textarea = $(`<textarea id="${obj.name}" class="vp-textarea">${(obj.default==undefined?'':obj.default)}</textarea>`);
+                // cell metadata test
+                if (getValue && obj.value != undefined) {
+                    // metadata 에 저장된 값으로 표시
+                    textarea.val(obj.value);
+                }
+                $(tblInput).append(textarea);
+                break;
             case 'table':
                 // break;
             case 'file':
